pub struct Policy { /* private fields */ }Expand description
Policy type for compliance proofs
Implementations
Sourceimpl Policy
impl Policy
Sourcepub fn aml_threshold(threshold: u64) -> Self
pub fn aml_threshold(threshold: u64) -> Self
Create an AML threshold policy
The prover will prove that the amount is strictly less than the threshold.
Args: threshold: The AML threshold value
Returns: Policy configured for AML threshold compliance
Sourcepub fn order_total_cap(cap: u64) -> Self
pub fn order_total_cap(cap: u64) -> Self
Create an order total cap policy
The prover will prove that the amount is less than or equal to the cap.
Args: cap: The order total cap value
Returns: Policy configured for order total cap compliance
Create an agent authorization policy.
The prover will prove that the amount is less than or equal to the delegated maximum total and bind the proof to the supplied delegated commerce intent hash.
Args: max_total: The delegated maximum total intent_hash: The delegated commerce intent hash (hex64)
Returns: Policy configured for delegated agent authorization